You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by mt...@apache.org on 2007/01/05 18:29:34 UTC

svn commit: r493095 - /tomcat/connectors/trunk/jni/native/build/buildcheck.sh

Author: mturk
Date: Fri Jan  5 09:29:25 2007
New Revision: 493095

URL: http://svn.apache.org/viewvc?view=rev&rev=493095
Log:
Update build tool dependencies.

Modified:
    tomcat/connectors/trunk/jni/native/build/buildcheck.sh

Modified: tomcat/connectors/trunk/jni/native/build/buildcheck.sh
URL: http://svn.apache.org/viewvc/tomcat/connectors/trunk/jni/native/build/buildcheck.sh?view=diff&rev=493095&r1=493094&r2=493095
==============================================================================
--- tomcat/connectors/trunk/jni/native/build/buildcheck.sh (original)
+++ tomcat/connectors/trunk/jni/native/build/buildcheck.sh Fri Jan  5 09:29:25 2007
@@ -7,26 +7,26 @@
 if test -z "$python"; then
 echo "buildconf: python not found."
 echo "           You need python installed"
-echo "           to build APR from CVS."
+echo "           to build Tomcat Native from SVN."
 exit 1
 else
 py_version=`python -c 'import sys; print sys.version' 2>&1|sed 's/ .*//;q'`
 echo "buildconf: python version $py_version (ok)"
 fi
 
 # autoconf 2.13 or newer
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
 if test -z "$ac_version"; then
 echo "buildconf: autoconf not found."
-echo "           You need autoconf version 2.13 or newer installed"
-echo "           to build Apache from CVS."
+echo "           You need autoconf version 2.50 or newer installed"
+echo "           to build Tomcat Native from SVN."
 exit 1
 fi
 IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "13" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "50" || test "$1" -lt "2"; then
 echo "buildconf: autoconf version $ac_version found."
-echo "           You need autoconf version 2.13 or newer installed"
-echo "           to build Apache from CVS."
+echo "           You need autoconf version 2.50 or newer installed"
+echo "           to build Tomcat Native from SVN."
 exit 1
 else
 echo "buildconf: autoconf version $ac_version (ok)"
@@ -37,27 +37,21 @@
 # ltmain.sh (GNU libtool 1.1361 2004/01/02 23:10:52) 1.5a
 # output is multiline from 1.5 onwards
 
-# Require libtool 1.3.3 or newer
+# Require libtool 1.4 or newer
 libtool=`build/PrintPath glibtool libtool libtool15 libtool14`
 lt_pversion=`$libtool --version 2>/dev/null|sed -e 's/([^)]*)//g;s/^[^0-9]*//;s/[- ].*//g;q'`
 if test -z "$lt_pversion"; then
 echo "buildconf: libtool not found."
-echo "           You need libtool version 1.3.3 or newer installed"
-echo "           to build Apache from CVS."
+echo "           You need libtool version 1.4 or newer installed"
+echo "           to build Tomcat Native from SVN."
 exit 1
 fi
 lt_version=`echo $lt_pversion|sed -e 's/\([a-z]*\)$/.\1/'`
 IFS=.; set $lt_version; IFS=' '
 lt_status="good"
 if test "$1" = "1"; then
-   if test "$2" -lt "3"; then
+   if test "$2" -lt "4"; then
       lt_status="bad"
-   else
-      if test "$2" = "3"; then
-         if test -z "$3" -o "$3" = "1" -o "$3" = "2"; then
-            lt_status="bad"
-         fi
-      fi
    fi
 fi
 if test $lt_status = "good"; then
@@ -66,7 +60,7 @@
 fi
 
 echo "buildconf: libtool version $lt_pversion found."
-echo "           You need libtool version 1.3.3 or newer installed"
-echo "           to build Apache from CVS."
+echo "           You need libtool version 1.4 or newer installed"
+echo "           to build Tomcat Native from SVN."
 
 exit 1



---------------------------------------------------------------------
@@ -7,26 +7,26 @@
 fi
 
-# autoconf 2.13 or newer
+# autoconf 2.50 or newer
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
 if test -z "$ac_version"; then
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org